//!
//! Resposible for running a node
//! in the backgorund
//!
pub mod daemon;

pub use crate::daemon::daemon::daemon_startup;

#[cfg(test)]

mod tests {
    use super::daemon::*;
    #[test]
    fn test_daemon() -> std::io::Result<()> {
        let _dpid = daemon_startup("test_blockchaindb");
        Ok(())
    }
}
